@@ -75,16 +75,17 @@ check_matrix <- function(x) {
 #'   transition matrices, one per cycle).
 #'   
 #' @keywords internal
-eval_transition <- function(x, ...) {
+eval_transition <- function(x, parameters) {
   UseMethod("eval_transition")
 }
 
+#' @export
 eval_transition.uneval_matrix <- function(x, parameters) {
   
   # update calls to dispatch_strategy()
   x <- dispatch_strategy_hack(x)
   
-  x_tidy <- compat_lazy_dots(x)
+  x_tidy <- x
   
   p2 <- parameters
   p2$C <- -pi
